A class definition to store codon automorphisms in a given Abelian group representation.
Source:R/allClasses.R
BaseGroup.RdA class definition to store codon automorphisms in a given Abelian group representation.

R/allClasses.R
BaseGroup.RdA class definition to store codon automorphisms in a given Abelian group representation.